@@ -53,10 +53,7 @@ class Presentation:
         with open(file, mode='w') as output:
             self._copyInOutput(output, asset1)
             for slideId in slideIds:
-                htmlLinks = slides.getMarkdownLinks(
-                    links[slideId], version) if links and slideId in links else None
-                self._writeMarkdownSection(output,slideId,
-                                           slides.getSlideContents(slideId, version), htmlLinks)
+                self._writeMarkdownSection(output, slideId, slides, version, links)
             self._copyInOutput(output, asset2)
 
         return file
@@ -102,7 +99,12 @@ class Presentation:
         with open(content, mode='r') as file:
             output.write(file.read())
 
-    def _writeMarkdownSection(self, output, slideId, slideContents, links=None):
+    def _writeMarkdownSection(self, output, slideId, slides, version, slideLinks):
+
+        links = slides.getMarkdownLinks(
+            slideLinks[slideId], version) if slideLinks and slideId in slideLinks else None
+        slideContents = slides.getSlideContents(slideId, version)
+        showLinks = slides.showLinks(slideId, version)
 
         end = '\n</section>'
         closeContentSection = '\n</textarea>'
@@ -125,13 +127,29 @@ class Presentation:
             content += openSection2
             content += slideContent
 
-            if index == len(slideContents) - 1 and links and len(links) > 1:
-                sep = '-'
-                link_line = "  \n"+sep.join(links)
-                content += link_line
-  
+            if showLinks:
+                print('showLinks')
+                line = self._getLinkLine(links, index, slideContents)
+                print(line)
+                content += line
+
             content += closeContentSection
             content += closeSection
 
         content += end
         output.write(content)
+
+    def _getLinkLine(self, links, index, slideContents):
+
+        print('links', links)
+        print('index', index)
+        print('slideContents', len(slideContents))
+
+        if not links:
+            return ''
+
+        if index != len(slideContents) - 1:
+            return ''
+
+        sep = '-'
+        return "  \n"+sep.join(links)
