@@ -107,6 +107,13 @@ class Slides:
         """returns the highest version value fourn for at least 1 slide in the collection"""
         return self.versions[-1]
 
+    def showLinks(self, slideId, version):
+        slides = self.getSlide(slideId, version)
+        show = True
+        for part in slides:
+            show = show and slides[part].showLinks
+        return show
+
     def getSlide(self, slideId, version=0):
         """returns a dictionary with key = part number and value = Slide object corresponding to the slide id and its version. 
         If no version is provided, version 0.0 is returned."""
